<%@ page session="false" %>
<%@ taglib prefix="cms" uri="http://www.opencms.org/taglib/cms" %>
<%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
<%@ taglib prefix="fn" uri="http://java.sun.com/jsp/jstl/functions" %>
<%@ taglib prefix="fmt" uri="http://java.sun.com/jsp/jstl/fmt" %>
<fmt:setLocale value="${pageContext.response.locale}" />
<fmt:bundle basename="com/levsys/modules/blog/strings">
	<jsp:useBean id="blog" class="com.levsys.modules.blog.Blog"><% 
	blog.init(pageContext, request, response); 
	%></jsp:useBean>
	
	<%-- load the blog page config to get the location of the blog entries --%>
	<cms:contentload collector="singleFile" param="%(opencms.uri)">
		<cms:contentaccess var="pcontent" scope="page" />
	</cms:contentload>
	
	<c:set var="blogEntryType"><cms:property name="blogentry.type" file="search" /></c:set>
	<c:set var="cmsObject" value="${cms:getCmsObject(pageContext)}" />
	<c:set var="baseCategoryFolder">/_categories/</c:set>
	<c:set var="vfs" value="${cms:vfs(pageContext)}" />
	<c:set var="extraTitle" value="" />
	
	<%-- set the pagination variables --%>
	<c:set var="page" value="1" scope="request" />
	<c:set var="pageSize" value="${itemsPerPage}" scope="request" />
	<c:set var="pageNavLength" value="5" scope="request" />
	<c:set var="start" value="0" scope="request" />

	<%-- set the default collector and limit the initial blog page to 10 blog entries --%>
	<c:set var="collector" value="allInSubTreeDateReleasedDesc" />
	<c:set var="collectorParam" value="${blogFolder}|${blogEntryType}" />
	
	<%-- if we have a date param append the date to the blogFolder to get contents from the right folder --%>
	<c:if test="${param.date != null}">
		<c:set var="collectorParam" value="${blogFolder}${param.date}|${blogEntryType}" />
	</c:if>
	
	<%-- if we have a tag param use the category collector --%>
	<c:if test="${param.category != null}">
		<%-- check for category.folder property --%>
		<c:set var="categoryFolder" value="blog/" />
		<c:set var="lcf"><cms:property name="category.folder" file="search" /></c:set>
		<c:if test="${not empty lcf}"><c:set var="categoryFolder" value="${lcf}" /></c:if>
		
		<%-- set the category folder path --%>
		<c:set var="categoryFolder" value="${categoryFolder}${param.category}/" />
		<c:set var="extraTitle">&nbsp;-&nbsp;<cms:property name="Title" file="${baseCategoryFolder}${categoryFolder}" /></c:set>
		
		<c:set var="collector" value="allKeyValuePairFiltered" />
		<c:set var="collectorParam" value="resource=${blogFolder}|categoryTypes=${categoryFolder}|resourceType=${blogEntryType}|subTree=true|sortBy=date|sortAsc=true" />
	</c:if>
	
	<c:if test="${param.page != null}"><c:set var="page" value="${param.page}" scope="request" /></c:if>
	
	<h1><c:out value="${pcontent.value['Title']}" /><c:out value="${extraTitle}" escapeXml="false" /></h1>
	
	<cms:contentload collector="${collector}" param="${collectorParam}" preload="true">
		<cms:contentinfo var="pinfo" />
		
		<c:choose>
			<c:when test="${pinfo.resultSize > 0}">
				<cms:contentload pageIndex="${page}" pageSize="${pageSize}" pageNavLength="${pageNavLength}" editable="true">
				
					<cms:contentinfo var="info" scope="request" />
					<cms:contentaccess var="content" scope="page" /> 
				
					<c:if test="${start == 0}"><c:set var="start" value="${info.resultIndex}" scope="request" /></c:if>
					
					<%-- increment the entry count so we can output a no entries if the date param is passed to this page --%>
					<c:set var="entryCount" value="${entryCount + 1}" />
					
					<div class="blogentry">
						<%-- output the title of the entry --%>
						<h2>
							<c:choose>
								<c:when test="${entryStyle eq 'short'}">
									<a href="<cms:link><c:out value="${content.filename}" /></cms:link>" title="<c:out value="${content.value['Title']}" />"><c:out value="${content.value['Title']}" /></a>
								</c:when>
								<c:otherwise>
									<c:out value="${content.value['Title']}" />
								</c:otherwise>
							</c:choose>
						</h2>
						
						<%-- output the posted by info --%>
						<p class="posted">
						
							<%-- output the date and user created of the blog entry --%>
							<jsp:setProperty name="blog" property="currentFilename" value="${content.filename}" />
							<c:set var="userCreated" value="${blog.userCreatedForResource}" />
							<fmt:message key="blog.posted" />: <fmt:formatDate value="${cms:convertDate(content.value['Date'])}" dateStyle="${dateStyle}" type="date" />
							
							<c:if test="${displayPostedBy}">
								<fmt:message key="blog.by" /> <c:out value="${userCreated.firstname} ${userCreated.lastname}" />
							</c:if>
							
							<%-- output the categories for this blog entry --%>
							<c:choose>
								<c:when test="${fn:length(content.valueList['Category']) > 1}">
									<fmt:message key="blog.incategories" /> 
								</c:when>
								<c:when test="${fn:length(content.valueList['Category']) == 1}">
									<fmt:message key="blog.incategory" /> 
								</c:when>
							</c:choose>
							<c:forEach items="${content.valueList['Category']}" var="c" varStatus="status">
								<c:set var="cp" value="${baseCategoryFolder}${fn:substringAfter(c, baseCategoryFolder)}" />
								
								<%-- get the resource so we can read the folder name --%>
								<c:set var="cr" value="${vfs.resource[cp]}" />
								<c:set var="ct"><cms:property name="Title" file="${cp}" /></c:set>
								<a href="<cms:link><c:out value="${blogPage}" /></cms:link>?category=<c:out value="${cr.name}" />"><c:out value="${ct}" /></a><c:if test="${not status.last}">, </c:if>
							</c:forEach>
						</p>
						
						<%-- output the blog content - short or long --%>
						<c:choose>
							<c:when test="${entryStyle eq 'short'}">
								<p><c:out value="${cms:trimToSize(cms:stripHtml(content.value['BlogText']), 255)}" escapeXml="false" /></p>
							</c:when>
							<c:otherwise>
								<c:out value="${content.value['BlogText']}" escapeXml="false" />
							</c:otherwise>
						</c:choose>
						
						<div class="entryinfo">
						
							<%-- output the tags for this blog entry --%>
							<c:if test="${content.hasValue['Tag']}">
								<span class="tags">
									<span>
										<c:choose>
											<c:when test="${fn:length(content.valueList['Tag']) == 1}">
												<fmt:message key="blog.singletag" />:
											</c:when>
											<c:otherwise>
												<fmt:message key="blog.tags" />:
											</c:otherwise>
										</c:choose>
									</span>
									<c:forEach items="${content.valueList['Tag']}" var="t" varStatus="status">
										<a href="<cms:link><c:out value="${blogPage}" /></cms:link>?tag=<c:out value="${t}" />"><c:out value="${t}" /></a><c:if test="${not status.last}">, </c:if>
									</c:forEach>
								</span>
							</c:if>
							
							<%-- output a count of approved comments --%>
							<c:if test="${enableComments}">
								<c:set var="approvedCommentsCount" value="0" />
								<c:forEach items="${content.valueList['Comment']}" var="comment">
									<c:if test="${comment.hasValue['Approved'] && comment.value['Approved'].stringValue eq 'true'}">
										<c:set var="approvedCommentsCount" value="${approvedCommentsCount + 1}" />
									</c:if>
								</c:forEach>
								<c:choose>
									<c:when test="${approvedCommentsCount > 1}">
										<span class="comments">
											<span><a href="<cms:link><c:out value="${content.filename}" /></cms:link>#comments"><fmt:message key="blog.comments" /></a></span>
											(<c:out value="${approvedCommentsCount}" />)
										</span>
									</c:when>
									<c:when test="${approvedCommentsCount == 1}">
										<span class="comments">
											<span><a href="<cms:link><c:out value="${content.filename}" /></cms:link>#comments"> 1 <fmt:message key="blog.singlecomment" /></a></span>
										</span>
									</c:when>
								</c:choose>
							</c:if>
						</div>
					</div>
					
				</cms:contentload>
				
				<c:if test="${pinfo.resultSize > pageSize}">
					<%--<cms:include file="/system/modules/com.levsys.modules.blog/elements/pagination.jsp" />--%>
					<c:if test="${not empty start && not empty info && not empty page && not empty pageNavLength}">
						<c:if test="${(info.resultSize > pageSize) && (info.resultIndex % info.pageSize == 0 || info.resultIndex == info.resultSize)}">
							<%-- build a queryString excluding any page params --%>
							<c:set var="queryString" value="" />
							<c:forEach var="parameter" items="${paramValues}">
								<c:if test="${parameter.key ne 'page'}">
							        	<c:forEach var="value" items="${parameter.value}">
							               		<c:set var="queryString" value="${queryString}&${parameter.key}=${value}" />
							            	</c:forEach>
						            	</c:if>
						      	</c:forEach>
							<div class="pagination">
								<p><fmt:message key="blog.pagination.showing" /> <c:out value="${start}" /> <fmt:message key="blog.pagination.to" /> <c:out value="${info.resultIndex}" /> <fmt:message key="blog.pagination.of" /> <c:out value="${info.resultSize}" /></p>
								<p>
									<c:if test="${page > 1 && info.pageCount > pageNavLength}">
										<a href="<cms:link><cms:info property="opencms.request.uri" />?page=1<c:out value="${queryString}" /></cms:link>"><fmt:message key="blog.pagination.first" /></a> 
										<span class="grey">|</span>
									</c:if>
									<c:if test="${page > 1}">
										<a href="<cms:link><cms:info property="opencms.request.uri" />?page=<c:out value="${page - 1}" /><c:out value="${queryString}" /></cms:link>"><fmt:message key="blog.pagination.previous" /></a> 
										<span class="grey">|</span>
									</c:if>
									<c:forEach begin="${info.pageNavStartIndex}" end="${info.pageNavEndIndex}" var="pageNo">
										<c:choose>
											<c:when test="${page == pageNo}">
												<c:out value="${pageNo}" /> 
											</c:when>
											<c:otherwise>
												<a href="<cms:link><cms:info property="opencms.request.uri" />?page=<c:out value="${pageNo}" /><c:out value="${queryString}" /></cms:link>"><c:out value="${pageNo}" /></a> 
											</c:otherwise>
										</c:choose>
									</c:forEach>
									<c:if test="${info.resultIndex != info.resultSize}">
										<span class="grey">|</span>
										<a href="<cms:link><cms:info property="opencms.request.uri" />?page=<c:out value="${page + 1}" /><c:out value="${queryString}" /></cms:link>"><fmt:message key="blog.pagination.next" /></a>
									</c:if>
									<c:if test="${info.resultIndex != info.resultSize && info.pageCount > pageNavLength}">
										<span class="grey">|</span>
										<a href="<cms:link><cms:info property="opencms.request.uri" />?page=<c:out value="${info.pageCount}" /><c:out value="${queryString}" /></cms:link>"><fmt:message key="blog.pagination.last" /></a>
									</c:if>
								</p>
							</div>
						</c:if>
					</c:if>
				</c:if>
				
			</c:when>
			<c:otherwise>
				<div class="blogentry">
					<p><fmt:message key="blog.entries.empty" />
						<c:if test="${param.date != null}">
							<fmt:parseDate pattern="yyyyMMdd" value="${param.date}01" type="date" var="dt" />
							<c:out value="${dt}" />
							<fmt:message key="blog.posted.in" /> &quot;<fmt:formatDate pattern="MMMMM yyyy" value="${dt}" />&quot;
						</c:if>
						<c:if test="${param.category != null}">
							<fmt:message key="blog.incategory" /> &quot;<cms:property name="Title" file="${baseCategoryFolder}${categoryFolder}" />&quot;
						</c:if>
					</p>
				</div>
			</c:otherwise>	
		</c:choose>
		
	</cms:contentload>
	
	<%-- output a no entries message if the date param was passed and no entries were counted --%>
	<c:if test="${param.date != null && entryCount == 0}">
		<div class="blogentry">
			<p><fmt:message key="blog.entries.empty" />
				<fmt:parseDate pattern="yyyyMMdd" value="${param.date}01" type="date" var="dt" />
				<fmt:message key="blog.posted.in" /> &quot;<fmt:formatDate pattern="MMMMM yyyy" value="${dt}" />&quot;
			</p>
		</div>
	</c:if>
</fmt:bundle>