<%@ page session="false" %>
<%@ taglib prefix="cms" uri="http://www.opencms.org/taglib/cms" %>
<%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
<%@ taglib prefix="fn" uri="http://java.sun.com/jsp/jstl/functions" %>
<%@ taglib prefix="fmt" uri="http://java.sun.com/jsp/jstl/fmt" %>
<fmt:setLocale value="${pageContext.response.locale}" />
<fmt:bundle basename="com/levsys/modules/blog/strings">
	<jsp:useBean id="blog" class="com.levsys.modules.blog.Blog"><% 
	blog.init(pageContext, request, response); 
	%></jsp:useBean>
	
	<cms:include property="template" element="head" />
	
	<c:set var="currentUri"><cms:info property="opencms.request.uri" /></c:set>
	<jsp:setProperty name="blog" property="currentFilename" value="${currentUri}" />
	<c:set var="baseCategoryFolder">/_categories/</c:set>
	<c:set var="vfs" value="${cms:vfs(pageContext)}" />
	<c:set var="enableComments" value="true" scope="request" />
	<c:set var="allowAnonymous" value="true" scope="request" />
	<c:set var="requireNameAndEmail" value="true" scope="request" />
	<c:set var="moderate" value="true" scope="request" />
	<c:set var="moderateEmailAddress" value="true" scope="request" />
	<c:set var="displayPostedBy" value="true" scope="request" />
	<c:set var="dateStyle" value="FULL" scope="request" />
	
	<%-- find the parent page --%>
	<c:set var="blogPage" scope="request" />
	<cms:contentload collector="allInSubTree" param="/|%(property.blogpage.type)">
		<cms:contentaccess var="bpcontent" scope="page" />
		<c:set var="thisBlogFolder" value="${bpcontent.value['BlogFolder']}" />
		<c:if test="${fn:contains(currentUri, thisBlogFolder)}">
			<c:set var="blogPage" scope="request" value="${bpcontent.filename}" />
			<c:set var="blogFolder" value="${bpcontent.value['BlogFolder']}" scope="request" />
			<%-- set the comment variables from the blog page defaults --%>
			<c:set var="enableComments" value="${bpcontent.value['EnableComments'].stringValue}" scope="request" />
			<c:set var="allowAnonymous" value="${bpcontent.value['AllowAnonymous'].stringValue}" scope="request" />
			<c:set var="requireNameAndEmail" value="${bpcontent.value['RequireNameAndEmail'].stringValue}" scope="request" />
			<c:set var="moderate" value="${bpcontent.value['Moderate'].stringValue}" scope="request" />
			<c:set var="moderateEmailAddress" value="${bpcontent.value['ModerateEmailAddress'].stringValue}" scope="request" />
			<c:set var="displayPostedBy" value="${bpcontent.value['DisplayPostedBy'].stringValue}" scope="request" />
			<c:set var="dateStyle" value="${bpcontent.value['DateStyle'].stringValue}" scope="request" />
		</c:if>
	</cms:contentload>
	
	<div id="blog-container">
	
		<div id="blog-content">
	    
			<cms:contentload collector="singleFile" param="%(opencms.uri)" editable="true">
				<cms:contentaccess var="content" scope="request" />
				
				<%-- set the comment variables if they have been overidden in the blog entry --%>
				<c:if test="${content.hasValue['EnableComments']}"><c:set var="enableComments" value="${content.value['EnableComments'].stringValue}" scope="request" /></c:if>
				<c:if test="${content.hasValue['AllowAnonymous']}"><c:set var="allowAnonymous" value="${content.value['AllowAnonymous'].stringValue}" scope="request" /></c:if>
		    
		    		<%-- output the title of the entry --%>
				<h1><c:out value="${content.value['Title']}" /></h1>
		    
		        	<div class="blogentry">
					<p class="posted">
						<%-- output the date and user created of the blog entry --%>
						<c:set var="userCreated" value="${blog.userCreatedForResource}" />
						<fmt:message key="blog.posted" />: <fmt:formatDate value="${cms:convertDate(content.value['Date'])}" dateStyle="${dateStyle}" type="date" />
						
						<c:if test="${displayPostedBy}">
							<fmt:message key="blog.by" /> <c:out value="${userCreated.firstname} ${userCreated.lastname}" />
						</c:if>
						
						<%-- output the categories for this blog entry --%>
						<c:choose>
							<c:when test="${fn:length(content.valueList['Category']) > 1}">
								<fmt:message key="blog.incategories" /> 
							</c:when>
							<c:when test="${fn:length(content.valueList['Category']) == 1}">
								<fmt:message key="blog.incategory" /> 
							</c:when>
						</c:choose>
						<c:forEach items="${content.valueList['Category']}" var="c" varStatus="status">
							<c:set var="cp" value="${baseCategoryFolder}${fn:substringAfter(c, baseCategoryFolder)}" />
							<%-- get the resource so we can read the folder name --%>
							<c:set var="cr" value="${vfs.resource[cp]}" />
							<c:set var="ct"><cms:property name="Title" file="${cp}" /></c:set>
							<a href="<cms:link><c:out value="${blogPage}" /></cms:link>?category=<c:out value="${cr.name}" />"><c:out value="${ct}" /></a><c:if test="${not status.last}">, </c:if>
						</c:forEach>
					</p>
					
					<%-- output the blog entry html --%>
					<c:out value="${content.value['BlogText']}" escapeXml="false" />
					
					<div class="entryinfo">
					
						<%-- output the tags for this blog entry --%>
						<c:if test="${content.hasValue['Tag']}">
							<span class="tags">
								<span>
									<c:choose>
										<c:when test="${fn:length(content.valueList['Tag']) == 1}">
											<fmt:message key="blog.singletag" />:
										</c:when>
										<c:otherwise>
											<fmt:message key="blog.tags" />:
										</c:otherwise>
									</c:choose>
								</span>
								<c:forEach items="${content.valueList['Tag']}" var="t" varStatus="status">
									<a href="<cms:link><c:out value="${blogPage}" /></cms:link>?tag=<c:out value="${t}" />"><c:out value="${t}" /></a><c:if test="${not status.last}">, </c:if>
								</c:forEach>
							</span>
						</c:if>
						
						<%-- output a count of approved comments --%>
						<c:if test="${enableComments eq 'true'}">
							<c:set var="approvedCommentsCount" value="0" />
							<c:forEach items="${content.valueList['Comment']}" var="comment">
								<c:if test="${comment.hasValue['Approved'] && comment.value['Approved'].stringValue eq 'true'}">
									<c:set var="approvedCommentsCount" value="${approvedCommentsCount + 1}" />
								</c:if>
							</c:forEach>
							<c:choose>
								<c:when test="${approvedCommentsCount > 1}">
									<span class="comments">
										<span><a href="<cms:link><c:out value="${content.filename}" /></cms:link>#comments"><fmt:message key="blog.comments" /></a></span>
										(<c:out value="${approvedCommentsCount}" />)
									</span>
								</c:when>
								<c:when test="${approvedCommentsCount == 1}">
									<span class="comments">
										<span><a href="<cms:link><c:out value="${content.filename}" /></cms:link>#comments"> 1 <fmt:message key="blog.singlecomment" /></a></span>
									</span>
								</c:when>
							</c:choose>
						</c:if>
					</div>
				</div>
		        </cms:contentload>
		        
		        <cms:include file="/system/modules/com.levsys.modules.blog/elements/comments.jsp">
		        	<cms:param name="enableComments" value="${enableComments}" />
		        	<cms:param name="allowAnonymous" value="${allowAnonymous}" />
		        </cms:include>
		        
		</div>

		<div id="blog-menu">
			
			<ul>
	            		<cms:include file="/system/modules/com.levsys.modules.blog/elements/info.jsp" />
		                <cms:include file="/system/modules/com.levsys.modules.blog/elements/search.jsp" />
				<cms:include file="/system/modules/com.levsys.modules.blog/elements/categories.jsp" />
				<cms:include file="/system/modules/com.levsys.modules.blog/elements/dates.jsp" />
				<cms:include file="/system/modules/com.levsys.modules.blog/elements/tags.jsp" />
				<cms:include file="/system/modules/com.levsys.modules.blog/elements/subscribe.jsp">
					<cms:param name="title" value="${bpcontent.value['Title']}" />
					<cms:param name="rssFeed" value="${bpcontent.value['RssFeed']}" />
					<cms:param name="atomFeed" value="${bpcontent.value['AtomFeed']}" />
				</cms:include>
			</ul>
			
		</div>
	
	</div>
	
	<div style="clear: both;"></div>
	
	<cms:include property="template" element="foot" />
</fmt:bundle>