package com.levsys.modules.blog;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.Locale;
import java.util.Map;
import org.apache.commons.logging.Log;
import org.opencms.configuration.CmsConfigurationManager;
import org.opencms.file.CmsObject;
import org.opencms.file.CmsProject;
import org.opencms.file.CmsProperty;
import org.opencms.file.CmsRequestContext;
import org.opencms.file.CmsResource;
import org.opencms.file.CmsUser;
import org.opencms.main.CmsContextInfo;
import org.opencms.main.CmsEvent;
import org.opencms.main.CmsException;
import org.opencms.main.CmsLog;
import org.opencms.main.OpenCms;
import org.opencms.module.A_CmsModuleAction;
import org.opencms.module.CmsModule;
import org.opencms.report.I_CmsReport;
import org.opencms.util.CmsUUID;

public class ActionClass extends A_CmsModuleAction
{
  private static final Log LOG = CmsLog.getLog(ActionClass.class);
  private static final int FOLDER = 0;
  private static final int LEVSYS_BLOG_FOLDER = 5002;
  private CmsObject adminCmsObject;
  private static ActionClass m_instance;

  public void initialize(CmsObject adminCms, CmsConfigurationManager configurationManager, CmsModule module)
  {
    super.initialize(adminCms, configurationManager, module);

    int[] eventTypes = { 2, 3, 11, 23 };

    OpenCms.addCmsEventListener(this, eventTypes);
    try
    {
      this.adminCmsObject = OpenCms.initCmsObject(adminCms);
    }
    catch (CmsException ex) {
      LOG.error(ex);
    }

    m_instance = this;
  }

  public void cmsEvent(CmsEvent event)
  {
    I_CmsReport report = (I_CmsReport)event.getData().get("report");

    Map m_eventData = event.getData();

    switch (event.getType())
    {
    case 23:
      CmsResource o_eventRes = (CmsResource)m_eventData.get("resource");
      if (o_eventRes.getTypeId() != 5002) return;
      if (LOG.isInfoEnabled())
        LOG.info("Creating year and month folders for this blog folder");
      try
      {
        CmsRequestContext context = this.adminCmsObject.getRequestContext();

        CmsUUID uid = o_eventRes.getUserCreated();
        CmsUser user = this.adminCmsObject.readUser(uid);

        CmsProject o_offlineProject = this.adminCmsObject.readProject("Offline");
        context.setCurrentProject(o_offlineProject);

        String blogfolder = o_eventRes.getRootPath();

        String requestedUri = this.adminCmsObject.getSitePath(o_eventRes);
        String siteRoot = context.getSiteRoot();
        Locale locale = context.getLocale();
        String encoding = context.getEncoding();
        String remoteAddr = context.getRemoteAddress();
        long requestTime = new Date().getTime();
        String ouFqn = context.getOuFqn();

        CmsContextInfo cinfo = new CmsContextInfo(user, o_offlineProject, requestedUri, siteRoot, locale, encoding, remoteAddr, requestTime, ouFqn);
        CmsObject thisCmsObject = OpenCms.initCmsObject(this.adminCmsObject, cinfo);

        GregorianCalendar cal = new GregorianCalendar();
        blogfolder = blogfolder + cal.get(1) + "/";

        thisCmsObject.createResource(blogfolder, 0);
        thisCmsObject.writePropertyObject(blogfolder, new CmsProperty("Title", "" + cal.get(1), "" + cal.get(1)));

        int month = cal.get(2) + 1;
        if (month < 10)
          blogfolder = blogfolder + "0" + month + "/";
        else {
          blogfolder = blogfolder + month + "/";
        }
        SimpleDateFormat sdf = new SimpleDateFormat("MMMMM yyyy");

        thisCmsObject.createResource(blogfolder, 0);
        thisCmsObject.writePropertyObject(blogfolder, new CmsProperty("Title", sdf.format(cal.getTime()), sdf.format(cal.getTime())));
      } catch (Exception ex) {
        LOG.error("Error creating default year and month folders", ex);
      }break;
    case 2:
    }
  }

  public CmsObject getAdminCmsObject()
  {
    return this.adminCmsObject;
  }

  public static ActionClass getInstance()
  {
    if (m_instance == null) {
      m_instance = new ActionClass();
    }
    return m_instance;
  }
}