package com.levsys.modules.blog;

import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.List;
import java.util.ResourceBundle;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.jsp.PageContext;
import org.apache.commons.logging.Log;
import org.opencms.file.CmsFile;
import org.opencms.file.CmsObject;
import org.opencms.file.CmsProject;
import org.opencms.file.CmsProperty;
import org.opencms.file.CmsRequestContext;
import org.opencms.file.CmsResource;
import org.opencms.file.CmsResourceFilter;
import org.opencms.file.CmsUser;
import org.opencms.i18n.CmsEncoder;
import org.opencms.jsp.CmsJspActionElement;
import org.opencms.mail.CmsSimpleMail;
import org.opencms.main.CmsException;
import org.opencms.main.CmsLog;
import org.opencms.main.OpenCms;
import org.opencms.publish.CmsPublishManager;
import org.opencms.site.CmsSiteManagerImpl;
import org.opencms.util.CmsUUID;
import org.opencms.xml.content.CmsXmlContent;
import org.opencms.xml.content.CmsXmlContentFactory;
import org.opencms.xml.types.I_CmsXmlContentValue;

public class Blog extends CmsJspActionElement
{
  private HttpServletRequest m_request;
  private static final Log LOG = CmsLog.INIT;
  private String blogFolder;
  private static final int FOLDER = 0;
  private static final int LEVSYS_BLOG_ENTRY = 5000;
  private static final int LEVSYS_BLOG_PAGE = 5001;
  private static final int LEVSYS_BLOG_FOLDER = 5002;
  private static final String FIELD_COMMENT = "Comment";
  private CmsResource currentResource;
  private String currentFilename;
  private String commentName;
  private String commentEmail;
  private String commentText;
  private boolean allowAnonymous = true;
  private boolean requireNameAndEmail = true;
  private boolean moderate = true;
  private String moderateEmailAddress;
  private String error;
  private String fullurl;
  private String workplaceServer;

  public void init(PageContext context, HttpServletRequest req, HttpServletResponse res)
  {
    super.init(context, req, res);
    this.m_request = req;
    this.fullurl = (req.getScheme() + "://" + req.getServerName());
    if (req.getServerPort() != 80) {
      this.fullurl = (this.fullurl + ":" + req.getServerPort());
    }

    this.workplaceServer = OpenCms.getSiteManager().getWorkplaceServer();
  }

  public List<CmsResource> getFoldersForPath()
    throws CmsException
  {
    if (this.blogFolder == null) {
      return null;
    }
    return getCmsObject().getResourcesInFolder(this.blogFolder, CmsResourceFilter.DEFAULT.addRequireType(0));
  }

  public List<CmsResource> getFoldersForPath(String path)
    throws CmsException
  {
    return getCmsObject().getResourcesInFolder(path, CmsResourceFilter.DEFAULT.addRequireType(0));
  }

  public List<CmsResource> getBlogEntriesForPath()
    throws CmsException
  {
    if (this.blogFolder == null) {
      return null;
    }
    return getCmsObject().getResourcesInFolder(this.blogFolder, CmsResourceFilter.DEFAULT.addRequireType(5000));
  }

  public List<CmsResource> getBlogEntriesForPath(String path)
    throws CmsException
  {
    return getCmsObject().getResourcesInFolder(path, CmsResourceFilter.DEFAULT.addRequireType(5000));
  }

  public CmsUser getUserCreatedForResource()
    throws CmsException
  {
    return getCmsObject().readUser(this.currentResource.getUserCreated());
  }

  public CmsUser getUserLastModifiedForResource()
    throws CmsException
  {
    return getCmsObject().readUser(this.currentResource.getUserLastModified());
  }

  public List<Date> getAllFolderDates()
    throws CmsException
  {
    ArrayList dates = new ArrayList();
    List years = getFoldersForPath();
    Date now = new Date();
    for (CmsResource y : years) {
      year = y.getName();
      List months = getFoldersForPath(this.blogFolder + year + "/");
      for (CmsResource m : months) {
        String month = m.getName();
        GregorianCalendar cal = new GregorianCalendar(Integer.parseInt(year), Integer.parseInt(month) - 1, 1);
        if ((cal.getTime().getTime() <= now.getTime()) && 
          (!dates.contains(cal.getTime())))
          dates.add(cal.getTime());
      }
    }
    String year;
    Collections.sort(dates, new DateComparator());
    Collections.reverse(dates);

    return dates;
  }

  public void setBlogFolder(String blogFolder)
  {
    this.blogFolder = blogFolder;
  }

  public void setCurrentResource(CmsResource currentResource)
  {
    this.currentResource = currentResource;
  }

  public void setCurrentFilename(String currentFilename)
    throws CmsException
  {
    this.currentFilename = currentFilename;
    this.currentResource = getCmsObject().readResource(currentFilename);
  }

  public void setCommentName(String commentName)
  {
    this.commentName = commentName;
  }

  public void setCommentEmail(String commentEmail)
  {
    this.commentEmail = commentEmail;
  }

  public void setCommentText(String commentText)
  {
    this.commentText = commentText;
  }

  public boolean getAddComment()
    throws CmsException
  {
    this.error = null;

    ResourceBundle labels = ResourceBundle.getBundle("com.levsys.modules.blog.strings", getCmsObject().getRequestContext().getLocale());

    CmsObject m_cms = ActionClass.getInstance().getAdminCmsObject();

    CmsProject currentProject = getCmsObject().getRequestContext().currentProject();

    CmsUser user = getCmsObject().getRequestContext().currentUser();

    String uri = getCmsObject().getRequestContext().getUri();

    String currentSiteRoot = getCmsObject().getRequestContext().getSiteRoot();

    String mSiteRoot = m_cms.getRequestContext().getSiteRoot();

    m_cms.getRequestContext().setSiteRoot(currentSiteRoot);

    if (!currentProject.isOnlineProject()) {
      this.error = labels.getString("blog.comments.submit.onlineonly");
      LOG.error(this.error + " to uri: " + uri);
      return false;
    }

    try
    {
      m_cms.getRequestContext().setCurrentProject(getCmsObject().readProject("Offline"));

      CmsFile file = m_cms.readFile(uri);

      if (file == null) {
        this.error = labels.getString("blog.comments.submit.filereaderror");
        LOG.error(this.error + ": " + uri);
        m_cms.getRequestContext().setCurrentProject(m_cms.readProject(CmsProject.ONLINE_PROJECT_ID));
        m_cms.getRequestContext().setSiteRoot(mSiteRoot);
        return false;
      }

      int commentCount = 0;
      CmsXmlContent content = CmsXmlContentFactory.unmarshal(m_cms, file);

      List comments = content.getValues("Comment", getRequestContext().getLocale());
      commentCount = comments.size();

      I_CmsXmlContentValue val = content.addValue(m_cms, "Comment", getRequestContext().getLocale(), commentCount);

      ++commentCount;
      String commentNdx = "[" + Integer.toString(commentCount) + "]";

      if ((!this.allowAnonymous) && (!user.isGuestUser())) {
        String userStr = user.getFirstname() + " " + user.getLastname();
        val = content.addValue(m_cms, "Comment" + commentNdx + "/User", getRequestContext().getLocale(), 0);
        val.setStringValue(m_cms, userStr);
      }

      val = content.addValue(m_cms, "Comment" + commentNdx + "/Anonymous", getRequestContext().getLocale(), 0);
      val.setStringValue(m_cms, Boolean.toString(this.allowAnonymous));

      val = content.addValue(m_cms, "Comment" + commentNdx + "/CommentName", getRequestContext().getLocale(), 0);
      val.setStringValue(m_cms, (this.commentName != null) ? this.commentName : "");

      val = content.addValue(m_cms, "Comment" + commentNdx + "/CommentEmail", getRequestContext().getLocale(), 0);
      val.setStringValue(m_cms, (this.commentEmail != null) ? this.commentEmail : "");

      val = content.getValue("Comment" + commentNdx + "/Date", getRequestContext().getLocale(), 0);
      val.setStringValue(m_cms, Long.toString(System.currentTimeMillis()));

      val = content.getValue("Comment" + commentNdx + "/Comment", getRequestContext().getLocale(), 0);
      val.setStringValue(m_cms, this.commentText);

      boolean approved = true;
      if (this.moderate) {
        approved = false;
      }
      val = content.getValue("Comment" + commentNdx + "/Approved", getRequestContext().getLocale(), 0);
      val.setStringValue(m_cms, Boolean.toString(approved));

      String decodedContent = content.toString();
      try {
        file.setContents(decodedContent.getBytes(CmsEncoder.lookupEncoding("UTF-8", "UTF-8")));
      } catch (UnsupportedEncodingException ex) {
        LOG.error(ex);
        this.error = ex.getMessage();
        m_cms.getRequestContext().setCurrentProject(m_cms.readProject(CmsProject.ONLINE_PROJECT_ID));
        m_cms.getRequestContext().setSiteRoot(mSiteRoot);
        return false;
      }

      m_cms.lockResource(m_cms.getSitePath(file));
      m_cms.writeFile(file);
      m_cms.unlockResource(m_cms.getSitePath(file));

      if (!this.moderate)
      {
        CmsPublishManager pm = OpenCms.getPublishManager();
        try {
          pm.publishResource(m_cms, m_cms.getSitePath(file));
          if (this.moderateEmailAddress == null)
            this.moderateEmailAddress = m_cms.readUser(file.getUserCreated()).getEmail();
        }
        catch (Exception ex) {
          LOG.error(ex);
          this.error = ex.getMessage();
          m_cms.getRequestContext().setCurrentProject(m_cms.readProject(CmsProject.ONLINE_PROJECT_ID));
          m_cms.getRequestContext().setSiteRoot(mSiteRoot);
          return false;
        }
      }

      try
      {
        CmsSimpleMail mail = new CmsSimpleMail();
        mail.setSubject(labels.getString("blog.comments.submit.email.subject") + ": " + m_cms.readPropertyObject(file, "Title", false).getValue());
        String msg = labels.getString("blog.comments.submit.email.body.intro") + ": " + this.fullurl + link(m_cms.getSitePath(file));
        msg = msg + "\n\n";
        msg = msg + labels.getString("blog.comments.submit.email.body.name") + ": " + this.commentName + "\n" + labels.getString("blog.comments.submit.email.body.email") + ": " + this.commentEmail + "\n" + labels.getString("blog.comments.submit.email.body.comment") + ": " + this.commentText;

        msg = msg + "\n\n";
        msg = msg + labels.getString("blog.comments.submit.email.body.workplace") + ": \n" + this.workplaceServer + link(new StringBuilder().append("/system/workplace/views/workplace.jsp?wpSite=").append(URLEncoder.encode(m_cms.getRequestContext().getSiteRoot(), "UTF-8")).append("&wpProject=").append(URLEncoder.encode(m_cms.getRequestContext().currentProject().getUuid().getStringValue(), "UTF-8")).append("&wpExplorerResource=").append(URLEncoder.encode(getCmsObject().getRequestContext().getFolderUri(), "UTF-8")).toString());

        mail.setMsg(msg);

        mail.addTo(this.moderateEmailAddress);
        mail.send();
      } catch (Exception ex) {
        LOG.error(ex);
        this.error = ex.getMessage();
        m_cms.getRequestContext().setCurrentProject(m_cms.readProject(CmsProject.ONLINE_PROJECT_ID));
        m_cms.getRequestContext().setSiteRoot(mSiteRoot);
        return false;
      }

      m_cms.getRequestContext().setCurrentProject(m_cms.readProject(CmsProject.ONLINE_PROJECT_ID));

      m_cms.getRequestContext().setSiteRoot(mSiteRoot);
    }
    catch (Exception ex) {
      LOG.error(ex);
      this.error = ex.getMessage();

      if (!m_cms.getRequestContext().currentProject().isOnlineProject()) {
        m_cms.getRequestContext().setCurrentProject(m_cms.readProject(CmsProject.ONLINE_PROJECT_ID));
      }
      return false;
    }

    return true;
  }

  public String getError()
  {
    return this.error;
  }

  public void setAllowAnonymous(boolean allowAnonymous)
  {
    this.allowAnonymous = allowAnonymous;
  }

  public void setRequireNameAndEmail(boolean requireNameAndEmail)
  {
    this.requireNameAndEmail = requireNameAndEmail;
  }

  public void setModerate(boolean moderate)
  {
    this.moderate = moderate;
  }

  public void setModerateEmailAddress(String moderateEmailAddress)
  {
    this.moderateEmailAddress = moderateEmailAddress;
  }
}